==> ros-rolling-ur-description_2.4.0.orig.tar.gz: ros-rolling-ur-description-2.4.0/ci_status.md <==
## Build Status

This page gives a detailed overview of the build status of this repository. Please note that due to
upstream changes some pipelines might turn red temporarily which can be expected behavior.

<table width="100%">
  <tr>
    <th></th>
    <th>Humble</th>
    <th>Iron</th>
    <th>Rolling</th>
  </tr>
  <tr>
    <th>Branch</th>
    <td><a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/tree/humble">humble</a></td>
    <td><a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/tree/iron">iron</a></td>
    <td><a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/tree/rolling">rolling</a></td>
  </tr>
  <tr>
    <th>Repo builds</th>
    <td>
      <a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/humble-binary-main.yml?query=event%3Aschedule++">
         <img src="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/humble-binary-main.yml/badge.svg?event=schedule"
              alt="Humble Binary Main"/>
      </a> <br />
      <a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/humble-binary-testing.yml?query=event%3Aschedule++">
         <img src="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/humble-binary-testing.yml/badge.svg?event=schedule"
              alt="Humble Binary Testing"/>
      </a> <br />
    </td>
    <td>
      <a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/iron-binary-main.yml?query=event%3Aschedule++">
         <img src="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/iron-binary-main.yml/badge.svg?event=schedule"
              alt="Iron Binary Main"/>
      </a> <br />
      <a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/iron-binary-testing.yml?query=event%3Aschedule++">
         <img src="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/iron-binary-testing.yml/badge.svg?event=schedule"
              alt="Iron Binary Testing"/>
      </a> <br />
    </td>
    <td>
      <a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/rolling-binary-main.yml?query=event%3Aschedule++">
         <img src="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/rolling-binary-main.yml/badge.svg?event=schedule"
              alt="Rolling Binary Main"/>
      </a> <br />
      <a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/rolling-binary-testing.yml?query=event%3Aschedule++">
         <img src="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/rolling-binary-testing.yml/badge.svg?event=schedule"
              alt="Rolling Binary Testing"/>
      </a> <br />
    </td>
  </tr>
  <tr>
    <th>Buildfarm</th>
    <td>
      <a href='https://build.ros2.org/job/Hbin_uJ64__ur_description__ubuntu_jammy_amd64__binary/'><img src='https://build.ros2.org/job/Hbin_uJ64__ur_description__ubuntu_jammy_amd64__binary/badge/icon?subject=uJ64_ur_description'></a>
    </td>
    <td>
      <a href='https://build.ros2.org/job/Ibin_uJ64__ur_description__ubuntu_jammy_amd64__binary/'><img src='https://build.ros2.org/job/Ibin_uJ64__ur_description__ubuntu_jammy_amd64__binary/badge/icon?subject=uJ64_ur_description'></a>
    </td>
    <td>
      <a href='https://build.ros2.org/job/Rbin_uJ64__ur_description__ubuntu_jammy_amd64__binary/'><img src='https://build.ros2.org/job/Rbin_uJ64__ur_description__ubuntu_jammy_amd64__binary/badge/icon?subject=uJ64_ur_description'></a>
    </td>
  </tr>
</table>

==> ros-rolling-ur-description_3.0.0.orig.tar.gz: ros-rolling-ur-description-3.0.0/ci_status.md <==
## Build Status

This page gives a detailed overview of the build status of this repository. Please note that due to
upstream changes some pipelines might turn red temporarily which can be expected behavior.

<table width="100%">
  <tr>
    <th></th>
    <th>Humble</th>
    <th>Jazzy</th>
    <th>Rolling</th>
  </tr>
  <tr>
    <th>Branch</th>
    <td><a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/tree/humble">humble</a></td>
    <td><a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/tree/rolling">rolling</a></td>
    <td><a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/tree/rolling">rolling</a></td>
  </tr>
  <tr>
    <th>Repo builds</th>
    <td>
      <a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/humble-binary-main.yml?query=event%3Aschedule++">
         <img src="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/humble-binary-main.yml/badge.svg?event=schedule"
              alt="Humble Binary Main"/>
      </a> <br />
      <a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/humble-binary-testing.yml?query=event%3Aschedule++">
         <img src="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/humble-binary-testing.yml/badge.svg?event=schedule"
              alt="Humble Binary Testing"/>
      </a> <br />
    </td>
    <td>
      <a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/jazzy-binary-main.yml?query=event%3Aschedule++">
         <img src="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/jazzy-binary-main.yml/badge.svg?event=schedule"
              alt="Jazzy Binary Main"/>
      </a> <br />
      <a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/jazzy-binary-testing.yml?query=event%3Aschedule++">
         <img src="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/jazzy-binary-testing.yml/badge.svg?event=schedule"
              alt="Jazzy Binary Testing"/>
      </a> <br />
    </td>
    <td>
      <a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/rolling-binary-main.yml?query=event%3Aschedule++">
         <img src="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/rolling-binary-main.yml/badge.svg?event=schedule"
              alt="Rolling Binary Main"/>
      </a> <br />
      <a href="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/rolling-binary-testing.yml?query=event%3Aschedule++">
         <img src="https://github.com/UniversalRobots/Universal_Robots_ROS2_Description/actions/workflows/rolling-binary-testing.yml/badge.svg?event=schedule"
              alt="Rolling Binary Testing"/>
      </a> <br />
    </td>
  </tr>
  <tr>
    <th>Buildfarm</th>
    <td>
      <a href='https://build.ros2.org/job/Hbin_uJ64__ur_description__ubuntu_jammy_amd64__binary/'><img src='https://build.ros2.org/job/Hbin_uJ64__ur_description__ubuntu_jammy_amd64__binary/badge/icon?subject=uJ64_ur_description'></a>
    </td>
    <td>
      <a href='https://build.ros2.org/job/Jbin_uN64__ur_description__ubuntu_noble_amd64__binary/'><img src='https://build.ros2.org/job/Jbin_uN64__ur_description__ubuntu_noble_amd64__binary/badge/icon?subject=uN64_ur_description'></a>
    </td>
    <td>
      <a href='https://build.ros2.org/job/Rbin_uN64__ur_description__ubuntu_noble_amd64__binary/'><img src='https://build.ros2.org/job/Rbin_uN64__ur_description__ubuntu_noble_amd64__binary/badge/icon?subject=uN64_ur_description'></a>
    </td>
  </tr>
</table>
